==> hatti-0.4.5-20180122.080631-1.jar: public/js/lib/out-prod/hatti/constants.js <==
// Compiled by ClojureScript 1.9.229 {:static-fns true, :optimize-constants true}
goog.provide('hatti.constants');
goog.require('cljs.core');
hatti.constants._attachments = "_attachments";
hatti.constants._edited = "_edited";
hatti.constants._id = "_id";
hatti.constants._last_edited = "_last_edited";
hatti.constants._notes = "_notes";
hatti.constants._rank = "_rank";
hatti.constants._submission_time = "_submission_time";
hatti.constants._media_all_received = "_media_all_received";
hatti.constants._submitted_by = "_submitted_by";
hatti.constants.photo = "Photo";
hatti.constants.download_url = "download_url";
hatti.constants.medium_download_url = "medium_download_url";
hatti.constants.small_download_url = "small_download_url";
hatti.constants.mimetype = "mimetype";
hatti.constants.google_sheets = "google_sheets";
hatti.constants.tiles_endpoint = "/services/postgis/logger_instance/geom/vector-tiles/{z}/{x}/{y}.pbf";
hatti.constants.vector_source_layer = "logger_instance_geom";
hatti.constants.mapboxgl_access_token = "pk.eyJ1Ijoib25hIiwiYSI6IlVYbkdyclkifQ.0Bz-QOOXZZK01dq4MuMImQ";
hatti.constants.map_styles = new cljs.core.PersistentVector(null, 7, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$style,"basic",cljs.core.cst$kw$name,"Mapbox Basic"], null),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$style,"outdoors",cljs.core.cst$kw$name,"Mapbox Outdoors"], null),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$style,"streets",cljs.core.cst$kw$name,"Mapbox Streets"], null),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$style,"bright",cljs.core.cst$kw$name,"Mapbox Bright"], null),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$style,"light",cljs.core.cst$kw$name,"Mapbox Light"], null),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$style,"dark",cljs.core.cst$kw$name,"Mapbox Dark"], null),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$style,"satellite-streets",cljs.core.cst$kw$name,"Mapbox Satellite"], null)], null);
hatti.constants.mapping_threshold = (10000);
hatti.constants.hexgrid_id = "hexgrid";
hatti.constants.hexbin_cell_width = (60);
hatti.constants.min_count_color = "#f2f5fc";
hatti.constants.max_count_color = "#08519c";
hatti.constants.failed_media_upload_error_message = "This media file was not uploaded successfully.";
hatti.constants.failed_media_upload_help_url = "knowledge-base/#";
/**
 * Define a help URL
 */
hatti.constants.help_base_url = (function hatti$constants$help_base_url(suffix){
return [cljs.core.str("http://help.ona.io/"),cljs.core.str(suffix)].join('');
});

==> hatti-0.4.6-20180921.082630-16.jar: public/js/lib/out-prod/hatti/constants.js <==
// Compiled by ClojureScript 1.9.229 {:static-fns true, :optimize-constants true}
goog.provide('hatti.constants');
goog.require('cljs.core');
hatti.constants._attachments = "_attachments";
hatti.constants._edited = "_edited";
hatti.constants._id = "_id";
hatti.constants._last_edited = "_last_edited";
hatti.constants._notes = "_notes";
hatti.constants._rank = "_rank";
hatti.constants._submission_time = "_submission_time";
hatti.constants._media_all_received = "_media_all_received";
hatti.constants._submitted_by = "_submitted_by";
hatti.constants._review_status = "_review_status";
hatti.constants._review_comment = "_review_comment";
hatti.constants.photo = "Photo";
hatti.constants.download_url = "download_url";
hatti.constants.medium_download_url = "medium_download_url";
hatti.constants.small_download_url = "small_download_url";
hatti.constants.mimetype = "mimetype";
hatti.constants.google_sheets = "google_sheets";
hatti.constants.tiles_endpoint = "/services/postgis/logger_instance/geom/vector-tiles/{z}/{x}/{y}.pbf";
hatti.constants.vector_source_layer = "logger_instance_geom";
hatti.constants.mapboxgl_access_token = "pk.eyJ1Ijoib25hIiwiYSI6IlVYbkdyclkifQ.0Bz-QOOXZZK01dq4MuMImQ";
hatti.constants.map_styles = new cljs.core.PersistentVector(null, 7, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$style,"basic",cljs.core.cst$kw$name,"Mapbox Basic"], null),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$style,"outdoors",cljs.core.cst$kw$name,"Mapbox Outdoors"], null),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$style,"streets",cljs.core.cst$kw$name,"Mapbox Streets"], null),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$style,"bright",cljs.core.cst$kw$name,"Mapbox Bright"], null),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$style,"light",cljs.core.cst$kw$name,"Mapbox Light"], null),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$style,"dark",cljs.core.cst$kw$name,"Mapbox Dark"], null),new cljs.core.PersistentArrayMap(null, 2, [cljs.core.cst$kw$style,"satellite-streets",cljs.core.cst$kw$name,"Mapbox Satellite"], null)], null);
hatti.constants.mapping_threshold = (10000);
hatti.constants.hexgrid_id = "hexgrid";
hatti.constants.hexbin_cell_width = (60);
hatti.constants.min_count_color = "#f2f5fc";
hatti.constants.max_count_color = "#08519c";
hatti.constants.failed_media_upload_error_message = "This media file was not uploaded successfully.";
hatti.constants.failed_media_upload_help_url = "knowledge-base/media-files-metadata-field/";
/**
 * Define a help URL
 */
hatti.constants.help_base_url = (function hatti$constants$help_base_url(suffix){
return [cljs.core.str("https://help.ona.io/"),cljs.core.str(suffix)].join('');
});
